#==============================================================================
# package      DE_EPAGES::Database::API::Constants
# state        public
#------------------------------------------------------------------------------
# description  Some constants
#==============================================================================
package DE_EPAGES::Database::API::Constants;
use base Exporter;

use strict;
our @EXPORT_OK = qw(
    LONG_STATEMENT_TIME
    NUMBER_OF_RETRIES
    RETRY_WAITING_TIME
    NO_SUCH_TABLE
    MAX_IN_CLAUSE_SIZE
);

use DE_EPAGES::Core::API::EpagesConfig qw ( EpagesConfig );

#========================================================================================
# global       LONG_STATEMENT_TIME | time in seconds that need to run over for logging
#               long running queries.
#               This value is configurable in the epages.conf file, section
#               DE_EPAGES::Database, key LongStatementTime.
#               Used for Sybase databases only! | integer
#========================================================================================
sub LONG_STATEMENT_TIME() { ## no critic qw(RequireCommentForExportedFunctions)
    return EpagesConfig()->get( 'DE_EPAGES::Database', 'LongStatementTime', 5 );
}

#========================================================================================
# function     NUMBER_OF_RETRIES
# state        public
#----------------------------------------------------------------------------------------
# syntax       NUMBER_OF_RETRIES();
# example      NUMBER_OF_RETRIES();
#----------------------------------------------------------------------------------------
# description  Function to retrieve the number of retries. This value is configurable in
#               the epages.conf file, section DE_EPAGES::Database, key NumberOfRetries.
#----------------------------------------------------------------------------------------
# return       $NumberOfRetries | How many times ePages should try to do a db action. | int
#========================================================================================
sub NUMBER_OF_RETRIES {
    return EpagesConfig()->get( 'DE_EPAGES::Database', 'NumberOfRetries', 5 );
}

#========================================================================================
# function     RETRY_WAITING_TIME
# state        public
#----------------------------------------------------------------------------------------
# syntax       RETRY_WAITING_TIME();
# example      RETRY_WAITING_TIME();
#----------------------------------------------------------------------------------------
# description  Function to retrieve the time to wait before retrying an action. This
#               value is configurable in the epages.conf file, section
#               DE_EPAGES::Database, key RetryWaitingTime.
#----------------------------------------------------------------------------------------
# return       $RetryWaitingTime | Waiting time in microseconds ePages waits before
#               retrying an action. | int
#========================================================================================
sub RETRY_WAITING_TIME {
    return EpagesConfig()->get( 'DE_EPAGES::Database', 'RetryWaitingTime', 1000 ); ## no critic qw(ProhibitMagicNumbers)
}

## MySQL specific error code
use constant NO_SUCH_TABLE => 1146;  ## no critic qw(ProhibitMagicNumbers)

# get objects from database in chunks of 500, because the number of items in the
# IN() clause is limited by ASE
use constant MAX_IN_CLAUSE_SIZE => 500;  ## no critic qw(ProhibitMagicNumbers)


1;
