#========================================================================================
# package      DE_EPAGES::GoogleSmartShopping::Hooks::ShortURL
# state        public
# description  create new uri for shorturl google*.hmtl
#========================================================================================
package DE_EPAGES::GoogleSmartShopping::Hooks::ShortURL;

use strict;

#========================================================================================
# function     OnShortUrlRedirect
# state        public
#----------------------------------------------------------------------------------------
# syntax       OnShortUrlRedirect( $hParams );
#----------------------------------------------------------------------------------------
# description  Sets new uri for short uri 'google*.hmtl'.
#               (Hook ShortUrlRedirect)
#----------------------------------------------------------------------------------------
# input        $hParams | primary key of tax class, key is
#               <ul>
#                   <li>Object - shop - object
#                   <li>URI - short URI - string
#                   <li>NewURI - new URI (set this parameter) - string
#               </ul> | ref.hash.*
#========================================================================================
sub OnShortUrlRedirect {
    my ($hParams) = @_;
    my $Shop = $hParams->{'Object'};
    my $Uri = $hParams->{'URI'};

    return unless defined $Uri;
    return unless $Uri =~  /^google[a-f0-9]+\.html$/;
    # There are two hooks that are executed on the same request, in Google and GoogleSmartShopping.
    # Allow only one hook to set the VieAction and NewURL.
    # Return if already set.
    return if defined $hParams->{'NewURI'};

    return unless ($Shop->existsChild('GoogleSmartShoppingConfig'));
    my $GoogleSmartShoppingConfig = $Shop->get('GoogleSmartShoppingConfig');
    my $GSSVerificationToken = $GoogleSmartShoppingConfig->get('SiteVerificationToken');
    return unless defined $GSSVerificationToken;
    return unless ($GSSVerificationToken eq $Uri);

    my $NewUri = $Shop->get('WebServerScriptName') . '/?ViewAction=';
    $NewUri .= 'UnitySF-ViewGoogleSmartShoppingHTML';
    $NewUri .= '&ChangeAction=BlockMonitor&ObjectID=' . $Shop->id;
    $hParams->{'NewURI'} = $NewUri;
}

1;
