#========================================================================================
# package      DE_EPAGES::PriceList::API::CSV::PriceListSimpleExportDriver;
# base         DE_EPAGES::ShopCSVExportImport::API::CSV::ShopObjectExportDriver
# state        public
#----------------------------------------------------------------------------------------
# description  This module implements a handler to export shop PriceLists via csv
#               This is a simplified version of the base exporter that uses a fixed pricelist
#               and has only a subset of the columns.
# example      use DE_EPAGES::PriceList::API::CSV::PriceListSimpleExportDriver;
#               DE_EPAGES::PriceList::API::CSV::PriceListSimpleExportDriver->exportCSV($FileName, $hFileFormat, $aColumns, $Shop );
#========================================================================================
package DE_EPAGES::PriceList::API::CSV::PriceListSimpleExportDriver;
use base qw( DE_EPAGES::PriceList::API::CSV::PriceListExportDriver );

use strict;
use DE_EPAGES::Core::API::Warning qw( Warning );
use DE_EPAGES::PriceList::API::PriceList qw (GetUnityPriceList);

#========================================================================================
# function     items
# state        public
#----------------------------------------------------------------------------------------
# syntax       my $Items = $self->items();
#----------------------------------------------------------------------------------------
# description  Remove all prices other than from the standard 'Unity' price list (bulk prices)
#----------------------------------------------------------------------------------------
# return       $ahData | parameter of exportCSV | ref.array.hash
#               <ul>
#                   <li>Product | product object | object
#                   <li>PriceList | pricelist object | object
#                   <li>Quantity | quantity for price and / or discount | float
#                   <li>Price | scaleprice | float
#                   <li>Discount | quantitydiscount as percental value | float
#                   <li>Value | value for discount | float
#                   <li>ValueDiscount | valuediscount as percental value | float
#               </ul>
#========================================================================================
sub items {
    my $self = shift;

    my $Shop = $self->{'Object'};

    my $ahItems = $self->SUPER::items();
    my $UnityPriceList = GetUnityPriceList($Shop, 1);

    for(my $i = 0; $i < scalar(@$ahItems); $i++) {
        if ( $ahItems->[$i]->{'PriceList'}->id != $UnityPriceList->id ) {
            splice(@$ahItems, $i, 1);
            $i--;
        }
    }

    my $ItemCount = scalar(@$ahItems);
    Warning('NO_PRICELISTITEMS') unless $ItemCount;
    my $Monitor = $self->monitor;
    $Monitor->set({'Total'=> $ItemCount}) if defined $Monitor;
    return $ahItems;
}

1;
