package DE_EPAGES::Zettle::t::02_ZettleUUIDClone;

use base DE_EPAGES::Shop::API::TestImportXML;
use Test::More;
use strict;
use warnings;

use DE_EPAGES::Product::API::Shop qw(GetProduct);

sub shopAlias { return 'TestShop'; }
sub importXMLPath { return 'TestShop.xml'; }

sub test {
    my $self = shift;
    my $Shop = $self->shop;

    # simple case with just a regular product
    my $Product = GetProduct($Shop, 'NormalProductWithPrice');
    $Product->set({'ZettleUUID' => 'fakeuuid'});
    ok($Product->get('ZettleUUID'), 'fakeuuid set for product');
    my $ProductClone = $Product->clone({'Alias' => 'NormalProductWithPriceClone'});
    ok($ProductClone, 'Product was cloned');
    ok(!$ProductClone->get('ZettleUUID'), 'ZettleUUID was not cloned');


    # and test with variations also
    my $UseMaster = 1;
    my $ProductWithVariations = GetProduct($Shop, 'be_40401', $UseMaster);
    ok($ProductWithVariations, 'Product with variations loaded');
    ok(scalar(@{$ProductWithVariations->get('SubProducts')}) > 0, 'Test product has variations');

    # set zettleuuid for the variations, use alias to get unique uuids even if it isn't enforced right now..
    foreach my $Variation (@{$ProductWithVariations->get('SubProducts')}) {
       $Variation->set({'ZettleUUID' => 'fakeuuid-'.$Variation->get('Alias') });
       ok($Variation->get('ZettleUUID'), 'fakeuuid set for variation');
    }

    # clone the master product
    my $Recursive = 1;
    my $ProductWithVariationsClone = $ProductWithVariations->clone({'Alias' => 'be_40401_clone'}, $Recursive);
    ok($ProductWithVariationsClone, 'Product with variations was cloned');

    # check that no one has zettleuuid
    ok(!$ProductWithVariationsClone->get('ZettleUUID'), 'ZettleUUID was not cloned for superproduct');
    foreach my $OneVariation (@{$ProductWithVariationsClone->get('SubProducts')}) {
      ok(!$OneVariation->get('ZettleUUID'), 'ZettleUUID was not cloned for variation');
    }

    done_testing();
}

__PACKAGE__->runScript;
1;
